//#define XERR
#include "random.ih"

double Random::uniform()
{
    return d_uniform(d_engine[UNIFORM]);
}
